@@ -21,8 +21,6 @@ FILTERS = (
     'sentry.filters.StatusFilter',
     'sentry.filters.LoggerFilter',
     'sentry.filters.LevelFilter',
-    'sentry.filters.ServerNameFilter',
-    'sentry.filters.SiteFilter',
 )
 
 KEY = None
@@ -35,6 +33,10 @@ LOG_LEVELS = (
     (logging.FATAL, 'fatal'),
 )
 
+DEFAULT_LOG_LEVEL = 'error'
+
+DEFAULT_LOGGER_NAME = 'root'
+
 ADMINS = []
 
 # Absolute URL to the sentry root directory. Should not include a trailing slash.
@@ -120,6 +122,10 @@ VIEWS = (
 # to create new projects
 ALLOW_PROJECT_CREATION = False
 
+# Should users without 'sentry.add_team' permissions be allowed
+# to create new projects
+ALLOW_TEAM_CREATION = False
+
 # Should users without superuser permissions be allowed to
 # make projects public
 ALLOW_PUBLIC_PROJECTS = True
